@@ -1,12 +1,11 @@
 """Contains grammars used by grascii."""
 
-import io
 from pathlib import Path
-from pkg_resources import resource_string
+
 
 def get_grammar(name: str) -> str:
     """Get a grammar string.
-    
+
     :param name: The name of the grammar resource.
     :returns: A grammar string.
     """
